@@ -6,7 +6,7 @@ use Dancer2::Plugin::Passphrase::Core;
 use Dancer2::Plugin::Passphrase::Hashed;
 use Dancer2::Plugin;
 
-our $VERSION = '3.3.2';
+our $VERSION = '3.3.4';
 
 plugin_keywords 'passphrase';
 
@@ -102,7 +102,7 @@ that is suitable for storage in a database.
 
 It returns a Dancer2::Plugin::Passphrase::Hashed object.
 
-You should store C<$phrase->rfc_2307()> in your database.
+You should store C<< $phrase->rfc_2307() >> in your database.
 
 Accepts a hashref of options to specify what kind of hash should be 
 generated. All options settable in the config file are valid.
@@ -128,7 +128,7 @@ So for Bcrypt this might be:
 
     my $phrase = passphrase('my password')->generate(
         {
-            algorith => 'Bcrypt',
+            algorithm => 'Bcrypt',
             Bcrypt   => {
                 cost => 14,
             }
@@ -214,7 +214,7 @@ The scheme name can be any of the following, and will always be capitalized
 
 Returns the algorithm name from a C<Dancer2::Plugin::Passphrase> object.
 
-The algorithm name can be anything that is accepted by C<Digest->new($alg)>
+The algorithm name can be anything that is accepted by C<< Digest->new($alg) >>
 This includes any modules in the C<Digest::> Namespace
 
     passphrase('my password')->generate->algorithm;
@@ -339,9 +339,7 @@ a strong psuedo-random salt.
     plugins:
         Passphrase:
             algorithm: Bcrypt
-
-            Bcrypt:
-                cost: 8
+            cost: 8
 
 
 =head2 Storage in a database
@@ -470,7 +468,7 @@ L<Dancer2>, L<Digest>, L<Crypt::Eksblowfish::Bcrypt>
 
 =item Sawyer X for his D2 magic.
 
-=item Mohammad S Anwar (GH#4)
+=item Mohammad S Anwar (GH#4, typo fixes)
 
 =item Jim Davis (GH#5)
 
@@ -480,6 +478,10 @@ L<Dancer2>, L<Digest>, L<Crypt::Eksblowfish::Bcrypt>
 
 =item Tom Adams (fix generate docs)
 
+=item Jeremi M. Gosney (GH #2)
+
+=item Sergiy Borodych (GH #3)
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
