@@ -6,6 +6,29 @@ use Digest;
 use MIME::Base64 qw(decode_base64 encode_base64);
 use Data::Entropy::Algorithms qw(rand_bits rand_int);
 
+# ABSTRACT: Passphrases and Passwords as objects for Dancer2
+
+=head1 NAME
+
+Dancer2::Plugin::Passphrase::Core - Core package for Dancer2::Plugin::Passphrase.
+
+=head1 DESCRIPTION
+
+B<FOR INTERNAL USE ONLY>
+
+=head1 AUTHOR
+
+Maintainer: Henk van Oers <hvoers@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by James Aitken.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
 sub new {
     my $class = shift;
     my @args  = @_;
@@ -22,13 +45,17 @@ sub _merge_options {
     # if we got options
     if ($options) {
         $algorithm = delete $options->{'algorithm'};
-        $settings  = $options->{$algorithm} // $self->{$algorithm};
+        $settings =
+          defined $options->{$algorithm}
+          ? $options->{$algorithm}
+          : $self->{$algorithm};
     }
 
     # Specify empty string to get an unsalted hash
     # Leaving it undefs results in 128 random bits being used as salt
     # bcrypt requires this amount, and is reasonable for other algorithms
-    $settings->{'salt'} //= rand_bits(128);
+    $settings->{'salt'} = rand_bits(128)
+      unless defined $settings->{'salt'};
 
     # RFC 2307 scheme is based on the algorithm, with a prefixed 'S' for salted
     $settings->{'scheme'} = join '', $algorithm =~ /[\w]+/g;
@@ -45,7 +72,8 @@ sub _merge_options {
     if ( $algorithm eq 'Bcrypt' ) {
         $settings->{'scheme'} = 'CRYPT';
         $settings->{'type'}   = '2a';
-        $settings->{'cost'}   = $settings->{'cost'} // 4;
+
+        $settings->{'cost'} //= $self->{'Bcrypt'}{'cost'} || 4;
         $settings->{'cost'}   = 31 if $settings->{'cost'} > 31;
         $settings->{'cost'}   = sprintf '%02d', $settings->{'cost'};
     }
